@@ -36,24 +36,24 @@ class Parser():
 
             # > python -m e_drone upgrade
             # > python -m e_drone update
-            if      (self.arguments[0] is "upgrade") or (self.arguments[0] is "update"):
+            if      (self.arguments[0] == "upgrade") or (self.arguments[0] == "update"):
                 updater = Updater()
                 updater.update()
                 return
 
             # > python -m e_drone request State 10 0.2
-            elif    ((self.count is 4) and 
-                    (self.arguments[0] is "request") and
-                    (self.arguments[1] is "state")):         # time interval
+            elif    ((self.count == 4) and 
+                    (self.arguments[0] == "request") and
+                    (self.arguments[1] == "state")):         # time interval
                 #print("* State - Ready     Blue    Red     Black   Black   NONE             1830   1631   2230      76      ")    
                 print ("         |ModeSystem   |ModeFlight |ModeControlFlight |ModeMovement |Headless |ControlSpeed |SensorOrientation |Battery |")
                 self.request(DeviceType.DRONE, DataType.STATE, int(self.arguments[2]), float(self.arguments[3]))
                 return
 
             # > python -m e_drone request Motion 10 0.2
-            elif    ((self.count is 4) and 
-                    (self.arguments[0] is "request") and
-                    (self.arguments[1] is "motion")):         # time interval
+            elif    ((self.count == 4) and 
+                    (self.arguments[0] == "request") and
+                    (self.arguments[1] == "motion")):         # time interval
                 #print("* Motion      -38      64     -32     457     -40    -400      16       0   20500")    
                 print ("         |Accel                  |Gyro                   |Angle                  |")
                 print ("         |      X|      Y|      Z|   Roll|  Pitch|    Yaw|   Roll|  Pitch|    Yaw|")
@@ -61,9 +61,9 @@ class Parser():
                 return
 
             # > python -m e_drone request CardRaw 10 0.2
-            elif    ((self.count is 4) and 
-                    (self.arguments[0] is "request") and
-                    (self.arguments[1] is "cardraw")):         # time interval
+            elif    ((self.count == 4) and 
+                    (self.arguments[0] == "request") and
+                    (self.arguments[1] == "cardraw")):         # time interval
                 #print("* CardRaw   335  503  766  692  309  395 100  39  96  40   9  17 303  61  39 344  77  15   Magenta         Red")
                 print ("          |Front Raw     |Rear Raw      |Front RGB  |Rear RGB   |Front HSVL      |Rear HSVL       |Front Color  |Rear Color   |")
                 print ("          |   R    G    B|   R    G    B|  R   G   B|  R   G   B|  H   S   V   L|  H   S   V   L|             |             |")
@@ -71,9 +71,9 @@ class Parser():
                 return
 
             # > python -m e_drone request CardRange 10 0.2
-            elif    ((self.count is 4) and 
-                    (self.arguments[0] is "request") and
-                    (self.arguments[1] is "cardrange")):         # time interval
+            elif    ((self.count == 4) and 
+                    (self.arguments[0] == "request") and
+                    (self.arguments[1] == "cardrange")):         # time interval
                 #print("* CardRange       200  2000   200  2000   200  2000   200     0   200     0   200     0")
                 print ("               |Front                              |Rear                               |")
                 print ("               |Red        |Green      |Blue       |Red        |Green      |Blue       |")
@@ -84,8 +84,8 @@ class Parser():
             # 이륙
             #                   0
             # python -m e_drone Takeoff
-            elif    ((self.count is 1) and 
-                    (self.arguments[0] is "takeoff")):
+            elif    ((self.count == 1) and 
+                    (self.arguments[0] == "takeoff")):
                 print (Fore.YELLOW + "takeoff" + Style.RESET_ALL)
                 self.command(CommandType.FLIGHT_EVENT, FlightEvent.TAKEOFF.value)
                 return
@@ -93,8 +93,8 @@ class Parser():
             # 착륙
             #                   0
             # python -m e_drone Landing
-            elif    ((self.count is 1) and 
-                    (self.arguments[0] is "landing")):
+            elif    ((self.count == 1) and 
+                    (self.arguments[0] == "landing")):
                 print (Fore.YELLOW + "landing" + Style.RESET_ALL)
                 self.command(CommandType.FLIGHT_EVENT, FlightEvent.LANDING.value)
                 return
@@ -102,8 +102,8 @@ class Parser():
             # 정지
             #                   0
             # python -m e_drone Stop
-            elif    ((self.count is 1) and 
-                    (self.arguments[0] is "stop")):
+            elif    ((self.count == 1) and 
+                    (self.arguments[0] == "stop")):
                 print (Fore.YELLOW + "stop" + Style.RESET_ALL)
                 self.command(CommandType.FLIGHT_EVENT, FlightEvent.STOP.value)
                 return
@@ -113,8 +113,8 @@ class Parser():
             # python -m e_drone control [roll] [pitch] [yaw] [throttle] [time(ms)]
             # 지정한 시간이 종료되면 입력값을 모두 0으로 변경하고 멈춤
             # > python -m e_drone control 40 0 3
-            elif    ((self.count is 6) and 
-                    (self.arguments[0] is "control")):
+            elif    ((self.count == 6) and 
+                    (self.arguments[0] == "control")):
                 print (Fore.YELLOW + "control" + Style.RESET_ALL)
                 self.control(int(self.arguments[1]), int(self.arguments[2]), int(self.arguments[3]), int(self.arguments[4]), int(self.arguments[5]))
                 return
@@ -122,8 +122,8 @@ class Parser():
             # 이동(전체)
             #                   0         1   2   3   4          5         6
             # python -m e_drone position [x] [y] [z] [velocity] [heading] [rotational velocity]
-            elif    ((self.count is 7) and 
-                    (self.arguments[0] is "position")):
+            elif    ((self.count == 7) and 
+                    (self.arguments[0] == "position")):
                 print (Fore.YELLOW + "position" + Style.RESET_ALL)
                 self.control_position(float(self.arguments[1]), float(self.arguments[2]), float(self.arguments[3]), float(self.arguments[4]), float(self.arguments[5]), float(self.arguments[6]))
                 return
@@ -131,8 +131,8 @@ class Parser():
             # 이동(위치)
             #                   0         1   2   3   4
             # python -m e_drone position [x] [y] [z] [velocity]
-            elif    ((self.count is 5) and 
-                    (self.arguments[0] is "position")):
+            elif    ((self.count == 5) and 
+                    (self.arguments[0] == "position")):
                 print (Fore.YELLOW + "position" + Style.RESET_ALL)
                 self.control_position(float(self.arguments[1]), float(self.arguments[2]), float(self.arguments[3]), float(self.arguments[4]), 0, 0)
                 return
@@ -140,8 +140,8 @@ class Parser():
             # 이동(헤딩)
             #                   0        1         2
             # python -m e_drone heading [heading] [rotational velocity]
-            elif    ((self.count is 3) and 
-                    (self.arguments[0] is "heading")):
+            elif    ((self.count == 3) and 
+                    (self.arguments[0] == "heading")):
                 print (Fore.YELLOW + "heading" + Style.RESET_ALL)
                 self.control_position(0, 0, 0, 0, float(self.arguments[1]), float(self.arguments[2]))
                 return
@@ -150,8 +150,8 @@ class Parser():
             #                   1       2    3
             # python -m e_drone buzzer [hz] [time(ms)]
             # > python -m e_drone buzzer 400 2000
-            elif    ((self.count is 3) and 
-                    (self.arguments[0] is "buzzer")):
+            elif    ((self.count == 3) and 
+                    (self.arguments[0] == "buzzer")):
                 print (Fore.WHITE + "Buzz Sound: " + Fore.YELLOW + "{0}".format(int(self.arguments[1])) + Fore.WHITE + "Hz, " + Fore.CYAN + "{0}".format(int(self.arguments[2])) + Fore.WHITE + "ms" + Style.RESET_ALL)
                 self.buzzer(DeviceType.CONTROLLER, int(self.arguments[1]), int(self.arguments[2]))
                 return
@@ -160,8 +160,8 @@ class Parser():
             #                   1         2          3           4
             # python -m e_drone vibrator [on(ms)] [off(ms)] [total(ms)]
             # > python -m e_drone vibrator 500 500 2000
-            elif    ((self.count is 4) and 
-                    (self.arguments[0] is "vibrator")):
+            elif    ((self.count == 4) and 
+                    (self.arguments[0] == "vibrator")):
                 print (Fore.WHITE + "Vibrator: on " + Fore.YELLOW + "{0}".format(int(self.arguments[1])) + Fore.WHITE + "ms, off " + Fore.CYAN + "{0}".format(int(self.arguments[2])) + Fore.WHITE + "ms, total " + Fore.CYAN + "{0}".format(int(self.arguments[3])) + Fore.WHITE + "ms" + Style.RESET_ALL)
                 self.vibrator(DeviceType.CONTROLLER, int(self.arguments[1]), int(self.arguments[2]), int(self.arguments[3]))
                 return
@@ -174,8 +174,8 @@ class Parser():
             # > python -m e_drone light body sunset 5 50 50 10
             # > python -m e_drone light body rainbow 8 50 50 10
             # > python -m e_drone light body rainbow2 8 50 50 10
-            elif    ((self.count is 7) and 
-                    (self.arguments[0] is "light")):
+            elif    ((self.count == 7) and 
+                    (self.arguments[0] == "light")):
                 print (Fore.WHITE + "Light: " + Fore.YELLOW + "{0}, {1}, {2}, ({3}, {4}, {5})".format(self.arguments[1], self.arguments[2], int(self.arguments[3]), int(self.arguments[4]), int(self.arguments[5]), int(self.arguments[6])) + Style.RESET_ALL)
                 self.light_mode_rgb(self.arguments[1], self.arguments[2], int(self.arguments[3]), int(self.arguments[4]), int(self.arguments[5]), int(self.arguments[6]))
                 return
@@ -185,8 +185,8 @@ class Parser():
             # > python -m e_drone light tail hold 100
             # > python -m e_drone light left hold 100
             # > python -m e_drone light right hold 100
-            elif    ((self.count is 4) and 
-                    (self.arguments[0] is "light")):
+            elif    ((self.count == 4) and 
+                    (self.arguments[0] == "light")):
                 print (Fore.WHITE + "Light: " + Fore.YELLOW + "{0}, {1}, {2}".format(self.arguments[1], self.arguments[2], int(self.arguments[3])) + Style.RESET_ALL)
                 self.light_mode_single(self.arguments[1], self.arguments[2], int(self.arguments[3]))
                 return
@@ -199,7 +199,7 @@ class Parser():
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
-        if drone.open() is False:
+        if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
         
@@ -219,7 +219,7 @@ class Parser():
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
-        if drone.open() is False:
+        if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
 
@@ -231,7 +231,7 @@ class Parser():
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
-        if drone.open() is False:
+        if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
 
@@ -244,7 +244,7 @@ class Parser():
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
-        if drone.open() is False:
+        if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
 
@@ -257,7 +257,7 @@ class Parser():
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
-        if drone.open() is False:
+        if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
         
@@ -269,37 +269,37 @@ class Parser():
 
         light_mode_high = LightModeDrone.NONE
 
-        if      str_light_part is "rear":
+        if      str_light_part == "rear":
             light_mode_high = LightModeDrone.REAR_NONE
-        elif    str_light_part is "body":
+        elif    str_light_part == "body":
             light_mode_high = LightModeDrone.BODY_NONE
-        elif    str_light_part is "a":
+        elif    str_light_part == "a":
             light_mode_high = LightModeDrone.A_NONE
-        elif    str_light_part is "b":
+        elif    str_light_part == "b":
             light_mode_high = LightModeDrone.B_NONE
 
         light_mode_low = LightModeDrone.NONE
 
-        if      str_light_mode is "hold":
+        if      str_light_mode == "hold":
             light_mode_low = LightModeDrone.BODY_HOLD
-        elif    str_light_mode is "flicker":
+        elif    str_light_mode == "flicker":
             light_mode_low = LightModeDrone.BODY_FLICKER
-        elif    str_light_mode is "flickerdouble":
+        elif    str_light_mode == "flickerdouble":
             light_mode_low = LightModeDrone.BODY_FLICKER_DOUBLE
-        elif    str_light_mode is "dimming":
+        elif    str_light_mode == "dimming":
             light_mode_low = LightModeDrone.BODY_DIMMING
-        elif    str_light_mode is "sunrise":
+        elif    str_light_mode == "sunrise":
             light_mode_low = LightModeDrone.BODY_SUNRISE
-        elif    str_light_mode is "sunset":
+        elif    str_light_mode == "sunset":
             light_mode_low = LightModeDrone.BODY_SUNSET
-        elif    str_light_mode is "rainbow":
+        elif    str_light_mode == "rainbow":
             light_mode_low = LightModeDrone.BODY_RAINBOW
-        elif    str_light_mode is "rainbow2":
+        elif    str_light_mode == "rainbow2":
             light_mode_low = LightModeDrone.BODY_RAINBOW2
 
         light_mode = LightModeDrone(light_mode_high.value + ((light_mode_low.value) & 0x0F))
 
-        if light_mode_high is not LightModeDrone.NONE and light_mode_low is not LightModeDrone.NONE:
+        if light_mode_high != LightModeDrone.NONE and light_mode_low != LightModeDrone.NONE:
             drone.send_light_mode_color(light_mode, interval, r, g, b)
 
 
@@ -307,7 +307,7 @@ class Parser():
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
-        if drone.open() is False:
+        if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
         
@@ -316,37 +316,37 @@ class Parser():
 
         light_mode_high = LightModeDrone.NONE
 
-        if      str_light_part is "rear":
+        if      str_light_part == "rear":
             light_mode_high = LightModeDrone.REAR_NONE
-        elif    str_light_part is "body":
+        elif    str_light_part == "body":
             light_mode_high = LightModeDrone.BODY_NONE
-        elif    str_light_part is "a":
+        elif    str_light_part == "a":
             light_mode_high = LightModeDrone.A_NONE
-        elif    str_light_part is "b":
+        elif    str_light_part == "b":
             light_mode_high = LightModeDrone.B_NONE
 
         light_mode_low = LightModeDrone.NONE
 
-        if      str_light_mode is "hold":
+        if      str_light_mode == "hold":
             light_mode_low = LightModeDrone.BODY_HOLD
-        elif    str_light_mode is "flicker":
+        elif    str_light_mode == "flicker":
             light_mode_low = LightModeDrone.BODY_FLICKER
-        elif    str_light_mode is "flickerdouble":
+        elif    str_light_mode == "flickerdouble":
             light_mode_low = LightModeDrone.BODY_FLICKER_DOUBLE
-        elif    str_light_mode is "dimming":
+        elif    str_light_mode == "dimming":
             light_mode_low = LightModeDrone.BODY_DIMMING
-        elif    str_light_mode is "sunrise":
+        elif    str_light_mode == "sunrise":
             light_mode_low = LightModeDrone.BODY_SUNRISE
-        elif    str_light_mode is "sunset":
+        elif    str_light_mode == "sunset":
             light_mode_low = LightModeDrone.BODY_SUNSET
-        elif    str_light_mode is "rainbow":
+        elif    str_light_mode == "rainbow":
             light_mode_low = LightModeDrone.BODY_RAINBOW
-        elif    str_light_mode is "rainbow2":
+        elif    str_light_mode == "rainbow2":
             light_mode_low = LightModeDrone.BODY_RAINBOW2
 
         light_mode = LightModeDrone(light_mode_high.value + ((light_mode_low.value) & 0x0F))
 
-        if light_mode_high is not LightModeDrone.NONE and light_mode_low is not LightModeDrone.NONE:
+        if light_mode_high != LightModeDrone.NONE and light_mode_low != LightModeDrone.NONE:
             drone.send_light_mode(light_mode, interval)
 
 
@@ -354,7 +354,7 @@ class Parser():
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
-        if drone.open() is False:
+        if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
         
@@ -382,7 +382,7 @@ class Parser():
 
         #drone = Drone(True, True, True, True, True)
         drone = Drone()
-        if drone.open() is False:
+        if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
         
@@ -398,7 +398,7 @@ class Parser():
         
         data = Vibrator()
 
-        data.mode       = VibratorMode.INSTANTALLY
+        data.mode       = VibratorMode.INSTANTLY
         data.on         = on
         data.off        = off
         data.total      = total
